# Внедрение картинок

Третья задача, которую решает `pandocster` - обеспечение корректного внедрения
картинок в результирующий документ. Непосредственно версткой-то занимается
`pandoc`, но он не умеет обрабатывать исходные файлы, лежащие в разных директориях
и с относительными путями в таком случае у пандока проблема. Скрипт `pandocster.py`
копирует медиаконтент в особое место и корректирует ссылки так, чтобы `pandoc`
с задачей справился.

Вот эту, к примеру, картинку `pandoc` сам "из коробки" в итоговых документ
не внедрит. Ее надо перенести в отдельную папку и поправить ссылку на абсолютную,
что и делает `pandocster`.

![Картинко](../assets/pandoc.png)
